/**
 * 月度表单逻辑层 
 * 作者: 陈金晶
 * 月度表单相关逻辑 包括孵化器月度填报的增删改查
 */
import { ERRORENUM } from "../../config/errorEnum";
import { BizError } from "../../util/bizError";
import * as monthData from "../../data/fuHuaQi/monthTable";
import { getTaskId } from "../../util/tools";
import moment = require("moment");
import { findAllFuHuaQiOperationNameMap, getFuHuaQiCreateDataTimeMap } from "../../data/fuHuaQi/fuhuaqi";

/**
 * 新添加孵化器月度填报
 * @param uscc 孵化器的统一信用代码
 * @param occupancyRate 本月出租率
 * @returns {isSuccess:true/false}
 */
export async function createReport(uscc:string, occupancyRate:number) {
    const TaskId = getTaskId(uscc);
    let dataBaseInfo = await monthData.findmonthTableByTaskId(TaskId);

    if (dataBaseInfo) throw new BizError(ERRORENUM.该孵化器月度填报已存在, `${uscc}重复提交了月度填报值为${occupancyRate}`);

    const MonthNumber = moment().subtract(1, 'months').month() + 1;
    const MonthTableName = `${MonthNumber}月孵化器月度填报`;
    await monthData.addOnceReport(TaskId, MonthTableName, uscc, occupancyRate);
    
    return {isSuccess:true};
}

/**
 * 修改孵化器月度报表
 * @param uscc 孵化器的统一信用代码
 * @param occupancyRate 本月出租率
 * @returns {isSuccess:true/false}
 */
export async function updateReport(uscc:string, occupancyRate:number) {
    const TaskId = getTaskId(uscc);
    let dataBaseInfo = await monthData.findmonthTableByTaskId(TaskId);
    if (!dataBaseInfo || !dataBaseInfo.taskId) throw new BizError(ERRORENUM.未找到数据, `未找到${uscc}的月度报表` );
    
    dataBaseInfo.occupancyRate = occupancyRate;
    await dataBaseInfo.save();

    return {isSuccess:true};
}

/**
 * 删除孵化器月度报表
 * @param uscc 孵化器的统一信用代码
 * @returns  {isSuccess:true/false}
 */
export async function deleteReport(uscc:string) {
    const TaskId = getTaskId(uscc);
    let dataBaseInfo = await monthData.findmonthTableByTaskId(TaskId);
    if (!dataBaseInfo || !dataBaseInfo.taskId) throw new BizError(ERRORENUM.未找到数据);

    await monthData.deleteReport(uscc, dataBaseInfo.name);

    return {isSuccess:true};
}


/**
 * 月度出租率数据列表
 * 管理后台使用
 * @param state 填报状态
 * @param year 数据年份
 * @param month 数据月份
 * @param page 页面
 */
export async function monthTableList(state:number, year:number, month:number, page:number) {
    let selectParam:any = {};
    if (year) selectParam.year = year;
    if (month) selectParam.month = month;

    if (state == 1) {
        let {dataList, count} = await getCompleted(selectParam, page);
        return {dataList, count};
    } else if (state == 2) {

    } else {
        let {dataList, count} = await getCompleted(selectParam, page);
        /**组合未填报 */
    }

   

    // let 需要组合未填报数 = 10 - dataList.length;
    
    
    // return {count, dataList};
}

async function getNotCompleted(year, month) {
    /** */
    getFuHuaQiCreateDataTimeMap();
}

/**
 * 获取已填报数据
 * @param selectParam 
 * @param page 
 * @returns 
 */
async function getCompleted(selectParam, page) {
    let dataBaseList = await monthData.findMonthTableList(selectParam, (page-1)*10 );
    let count = await monthData.findMonthTableListCount(selectParam);

    let operationNameMap = findAllFuHuaQiOperationNameMap();

    let dataList = [];
    dataBaseList.forEach( info => {
        let onceInfo = {
            operationName:operationNameMap[info.fuHuaQiUscc],
            state:'已填报',
            time:`${info.year}年${info.month}月`,
            occupancyRate:info.occupancyRate
        };
        dataList.push(onceInfo);
    });
    return {count, dataList}
}